==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/de_DE.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumente",
"Can't create document" => "Dokument kann nicht erstellt werden",
"You don't have permission to rename this document" => "Sie haben nicht die erforderlichen Rechte, dieses Dokument umzubenennen.",
"Directory saved successfully." => "Verzeichnis erfolgreich gespeichert.",
"An error occurred while changing directory." => "Es ist ein Fehler beim Wechseln des Verzeichnisses aufgetreten.",
"Saved" => "Gespeichert",
"Format filter server is down or misconfigured" => "Formatfilter-Server ist ausgeschaltet oder falsch konfiguriert",
"Conversion failed. Check log for details." => "Fehler bei der Konvertierung. Für Einzelheiten Log-Dateien prüfen.",
"bold" => "fett",
"italic" => "kursiv",
"pt" => "Pt",
"Saving..." => "Speichervorgang …",
"Failed to load documents." => "Das Laden der Dokumente ist fehlgeschlagen.",
"No documents were found. Upload or create a document to get started!" => "Keine Dokumente gefunden. Bitte laden Sie zu Beginn Dokumente hoch, oder erstellen Sie ein Dokument!",
"No connection to server. Trying to reconnect." => "Keine Verbindung zum Server. Es wird versucht diese wiederherzustellen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Das Verlassen dieser Seite kann zu nicht gespeicherten Daten führen. Bitte verwenden die den 'Schließen'-Button.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Es ist ein Fehler beim Laden dieses Dokumentes aufgetreten. Bitte überprüfen Sie, ob diese Datei mit einem externen ODT-Editor geöffnet werden kann. Dies könnte auch bedeuten, dass die Datei nicht mehr geteilt wird oder vor kurzem gelöscht wurde.",
"Save" => "Speichern",
"Loading documents..." => "Lade Dokumente…",
"'.' is an invalid file name." => "'.' ist kein gültiger Dateiname.",
"File name cannot be empty." => "Der Dateiname darf nicht leer sein.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ungültiger Name, '\\', '/', '<', '>', ':', '\"', '|', '?' und '*' sind nicht zulässig.",
"Align Left" => "Linksbündig",
"Alignment" => "Ausrichtung",
"Align Right" => "Rechtsbündig",
"Annotate" => "Kommentieren",
"Background" => "Hintergrund",
"Bold" => "Fett",
"Bottom" => "Unten",
"Cancel" => "Abbrechen",
"Center" => "Zentriert",
"Clone" => "Klonen",
"Clone this Style" => "Diesen Stil klonen",
"Close" => "Schließen",
"Color" => "Farbe",
"Create" => "Erstellen",
"Decrease Indent" => "Einrückung verkleinern",
"Default Style" => "Standard-Stil",
"Delete" => "Löschen",
"Family" => "Familie",
"Font" => "Schriftart",
"Font Effects" => "Schriftarten-Effekte",
"Format" => "Format",
"Increase Indent" => "Einrückung vergrößern",
"Insert Image" => "Bild einfügen",
"Invite Members" => "Mitglied einladen",
"Italic" => "Kursiv",
"Justified" => "Bündig",
"Justify" => "Ausrichten",
"Left" => "Links",
"Loading" => "Lade",
"Members" => "Mitglieder",
"New Name:" => "Neuer Name:",
"OK" => "OK",
"Open" => "Öffnen",
"Options" => "Optionen",
"Paragraph..." => "Absatz…",
"Paragraph Styles" => "Absatz-Stile",
"Redo" => "Wiederholen",
"Right" => "Rechts",
"Size" => "Größe",
"Spacing" => "Abstand",
"Strikethrough" => "Durchgestrichen",
"Style" => "Stil",
"Text" => "Text",
"Top" => "Oben",
"Underline" => "Unterstrichen",
"Undo" => "Rückgängig",
"Unknown Author" => "Unbekannter Autor",
"Edit" => "Bearbeiten",
"Share" => "Teilen",
"guest" => "Gast",
"MS Word support (requires openOffice/libreOffice)" => "MS Word Unterstützung (benötigt OpenOffice/LibreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "OpenOffice/LibreOffice ist auf diesem Server installiert. Der Pfad zur Binärdatei wird über preview_libreoffice_path in der config.php bereit gestellt.",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice ist auf einem externen Server installiert und läuft dort als Formatfilter-Server",
"Disabled" => "Deaktiviert",
"No MS Word support" => "Keine MS Word Unterstützung",
"scheme://domain.tld[:port]" => "Schema://Domain.tld[:port]",
"Server URL" => "Serveradresse",
"Apply and test" => "Übernehmen und Testen",
"New document" => "Neues Dokument",
"Upload (max. %s)" => "Hochladen (max. %s)",
"Upload" => "Hochladen",
"Save new documents to" => "Neues Dokument speichern unter",
"Wrong password. Please retry." => "Falsches Passwort. Bitte versuchen Sie es noch einmal.",
"Password" => "Passwort",
"Guest %s" => "Gast %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Dieser Link ist abgelaufen oder existierte niemals. Bitte kontaktieren Sie für nähere Details die Person, die dieses Dokument mit Ihnen geteilt hat.",
"Advanced feature-set" => "Erweiterte Funktionseinstellungen",
"(Unstable)" => "(Instabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/de_DE.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumente",
"Can't create document" => "Dokument kann nicht erstellt werden",
"You don't have permission to rename this document" => "Sie haben nicht die erforderlichen Rechte, dieses Dokument umzubenennen.",
"Directory saved successfully." => "Verzeichnis erfolgreich gespeichert.",
"An error occurred while changing directory." => "Es ist ein Fehler beim Wechseln des Verzeichnisses aufgetreten.",
"Saved" => "Gespeichert",
"Format filter server is down or misconfigured" => "Formatfilter-Server ist ausgeschaltet oder falsch konfiguriert",
"Conversion failed. Check log for details." => "Fehler bei der Konvertierung. Für Einzelheiten Log-Dateien prüfen.",
"Saving..." => "Speichervorgang …",
"Failed to load documents." => "Das Laden der Dokumente ist fehlgeschlagen.",
"No documents were found. Upload or create a document to get started!" => "Keine Dokumente gefunden. Bitte laden Sie zu Beginn Dokumente hoch, oder erstellen Sie ein Dokument!",
"No connection to server. Trying to reconnect." => "Keine Verbindung zum Server. Es wird versucht diese wiederherzustellen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Das Verlassen dieser Seite kann zu nicht gespeicherten Daten führen. Bitte verwenden die den 'Schließen'-Button.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Es ist ein Fehler beim Laden dieses Dokumentes aufgetreten. Bitte überprüfen Sie, ob diese Datei mit einem externen ODT-Editor geöffnet werden kann. Dies könnte auch bedeuten, dass die Datei nicht mehr geteilt wird oder vor kurzem gelöscht wurde.",
"Save" => "Speichern",
"Loading documents..." => "Lade Dokumente…",
"'.' is an invalid file name." => "'.' ist kein gültiger Dateiname.",
"File name cannot be empty." => "Der Dateiname darf nicht leer sein.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ungültiger Name, '\\', '/', '<', '>', ':', '\"', '|', '?' und '*' sind nicht zulässig.",
"Align Left" => "Linksbündig",
"Alignment" => "Ausrichtung",
"Align Right" => "Rechtsbündig",
"Annotate" => "Kommentieren",
"Background" => "Hintergrund",
"Bold" => "Fett",
"Bottom" => "Unten",
"Cancel" => "Abbrechen",
"Center" => "Zentriert",
"Clone" => "Klonen",
"Clone this Style" => "Diesen Stil klonen",
"Close" => "Schließen",
"Color" => "Farbe",
"Create" => "Erstellen",
"Decrease Indent" => "Einrückung verkleinern",
"Default Style" => "Standard-Stil",
"Delete" => "Löschen",
"Family" => "Familie",
"Font" => "Schriftart",
"Font Effects" => "Schriftarten-Effekte",
"Format" => "Format",
"Increase Indent" => "Einrückung vergrößern",
"Insert Image" => "Bild einfügen",
"Invite Members" => "Mitglied einladen",
"Italic" => "Kursiv",
"Justified" => "Bündig",
"Justify" => "Ausrichten",
"Left" => "Links",
"Loading" => "Lade",
"Members" => "Mitglieder",
"New Name:" => "Neuer Name:",
"OK" => "OK",
"Open" => "Öffnen",
"Options" => "Optionen",
"Paragraph..." => "Absatz…",
"Paragraph Styles" => "Absatz-Stile",
"Redo" => "Wiederholen",
"Right" => "Rechts",
"Size" => "Größe",
"Spacing" => "Abstand",
"Strikethrough" => "Durchgestrichen",
"Style" => "Stil",
"Text" => "Text",
"Top" => "Oben",
"Underline" => "Unterstrichen",
"Undo" => "Rückgängig",
"Unknown Author" => "Unbekannter Autor",
"Shared" => "Geteilt",
"Error" => "Fehler",
"Error while sharing" => "Fehler beim Teilen",
"Error while unsharing" => "Fehler beim Aufheben der Freigabe",
"Error while changing permissions" => "Fehler bei der Änderung der Rechte",
"Shared with you and the group {group} by {owner}" => "Von {owner} mit Ihnen und der Gruppe {group} geteilt.",
"Shared with you by {owner}" => "Von {owner} mit Ihnen geteilt.",
"Share with users or groups …" => "Mit Benutzern oder Gruppen teilen…",
"Share with users, groups or remote users …" => "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
"Share" => "Teilen",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
"Share link" => "Link teilen",
"The public link will expire no later than {days} days after it is created" => "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
"Link" => "Link",
"Password protect" => "Passwortschutz",
"Password" => "Passwort",
"Choose a password for the public link" => "Wählen Sie ein Passwort für den öffentlichen Link",
"Allow editing" => "Bearbeitung erlauben",
"Email link to person" => "Link per E-Mail verschicken",
"Send" => "Senden",
"Set expiration date" => "Ein Ablaufdatum setzen",
"Expiration" => "Ablaufdatum",
"Expiration date" => "Ablaufdatum",
"An error occured. Please try again" => "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
"Adding user..." => "Benutzer wird hinzugefügt…",
"group" => "Gruppe",
"remote" => "Entfernte Freigabe",
"Resharing is not allowed" => "Das Weiterverteilen ist nicht erlaubt",
"Shared in {item} with {user}" => "Freigegeben in {item} von {user}",
"Unshare" => "Freigabe aufheben",
"notify by email" => "per E-Mail benachrichtigen",
"can share" => "kann teilen",
"can edit" => "kann bearbeiten",
"access control" => "Zugriffskontrolle",
"create" => "erstellen",
"change" => "Ändern",
"delete" => "löschen",
"Password protected" => "Passwortgeschützt",
"Error unsetting expiration date" => "Fehler beim Entfernen des Ablaufdatums",
"Error setting expiration date" => "Fehler beim Setzen des Ablaufdatums",
"Sending ..." => "Senden…",
"Email sent" => "E-Mail gesendet",
"Warning" => "Warnung",
"Edit" => "Bearbeiten",
"guest" => "Gast",
"MS Word support (requires openOffice/libreOffice)" => "MS Word Unterstützung (benötigt OpenOffice/LibreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "OpenOffice/LibreOffice ist auf diesem Server installiert. Der Pfad zur Binärdatei wird über preview_libreoffice_path in der config.php bereit gestellt.",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "OpenOffice/LibreOffice ist auf einem externen Server installiert und läuft dort als Formatfilter-Server",
"Disabled" => "Deaktiviert",
"No MS Word support" => "Keine MS Word Unterstützung",
"scheme://domain.tld[:port]" => "Schema://Domain.tld[:port]",
"Server URL" => "Serveradresse",
"Apply and test" => "Übernehmen und Testen",
"New document" => "Neues Dokument",
"Upload (max. %s)" => "Hochladen (max. %s)",
"Upload" => "Hochladen",
"Save new documents to" => "Neues Dokument speichern unter",
"Wrong password. Please retry." => "Falsches Passwort. Bitte versuchen Sie es noch einmal.",
"Guest %s" => "Gast %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Dieser Link ist abgelaufen oder existierte niemals. Bitte kontaktieren Sie für nähere Details die Person, die dieses Dokument mit Ihnen geteilt hat.",
"Advanced feature-set" => "Erweiterte Funktionseinstellungen",
"(Unstable)" => "(Instabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
